#line 2 "dlexer.c"

#line 4 "dlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer d__create_buffer
#define yy_delete_buffer d__delete_buffer
#define yy_flex_debug d__flex_debug
#define yy_init_buffer d__init_buffer
#define yy_flush_buffer d__flush_buffer
#define yy_load_buffer_state d__load_buffer_state
#define yy_switch_to_buffer d__switch_to_buffer
#define yyin d_in
#define yyleng d_leng
#define yylex d_lex
#define yylineno d_lineno
#define yyout d_out
#define yyrestart d_restart
#define yytext d_text
#define yywrap d_wrap
#define yyalloc d_alloc
#define yyrealloc d_realloc
#define yyfree d_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE d_restart(d_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int d_leng;

extern FILE *d_in, *d_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up d_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up d_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via d_restart()), so that the user can continue scanning by
	 * just pointing d_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when d_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int d_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow d_wrap()'s to do buffer switches
 * instead of setting up a fresh d_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void d_restart (FILE *input_file  );
void d__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE d__create_buffer (FILE *file,int size  );
void d__delete_buffer (YY_BUFFER_STATE b  );
void d__flush_buffer (YY_BUFFER_STATE b  );
void d_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void d_pop_buffer_state (void );

static void d_ensure_buffer_stack (void );
static void d__load_buffer_state (void );
static void d__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER d__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE d__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE d__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE d__scan_bytes (yyconst char *bytes,int len  );

void *d_alloc (yy_size_t  );
void *d_realloc (void *,yy_size_t  );
void d_free (void *  );

#define yy_new_buffer d__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        d_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            d__create_buffer(d_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        d_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            d__create_buffer(d_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *d_in = (FILE *) 0, *d_out = (FILE *) 0;

typedef int yy_state_type;

extern int d_lineno;

int d_lineno = 1;

extern char *d_text;
#define yytext_ptr d_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up d_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	d_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 173
#define YY_END_OF_BUFFER 174
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[660] =
    {   0,
        0,    0,  111,  111,  118,  118,  145,  145,  151,  151,
      174,  172,  170,  167,  169,  144,  172,  172,  172,  156,
      156,  172,  171,  156,  150,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  111,  113,  114,  112,  118,
      122,  123,  119,  120,  145,  146,  147,  149,  173,  151,
      152,  153,  155,  168,  127,    0,    0,  110,  117,  126,
      156,  158,  159,  157,    0,    0,    0,    0,    0,  171,
      171,  156,  158,  159,  156,  171,  171,  171,  157,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,

      171,  171,  171,  171,  171,  171,  171,   77,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,   85,  171,   86,  171,   88,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  111,  115,  112,  112,  116,  118,  124,
      119,  119,  125,  120,  121,  120,  145,    0,  148,  151,
      154,  162,    0,  162,  126,  160,  161,    0,    0,    0,
        0,    0,  158,  159,  157,  160,  156,  171,  171,  171,

      171,  171,  171,  171,  171,  171,  171,   65,  171,  171,
        8,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,   80,
      171,  171,  171,  171,  171,  171,  171,  171,    6,  171,
      171,  171,  171,  171,  171,   90,  171,  171,   91,  171,
      171,  171,  171,  171,  171,  171,  171,  171,   41,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  102,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  163,    0,

        0,    0,    0,    0,  160,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,    5,
       67,    9,  171,    7,   69,   71,  171,  171,   12,  171,
       10,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,   78,   18,  171,  171,  171,  171,  171,  171,
      171,  171,   84,  171,  171,  171,  171,  171,  171,  171,
      171,  171,   34,   35,  171,  171,  171,  165,  171,  171,
      171,  171,  171,  171,  171,   39,   40,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,   99,
      171,  166,  171,  171,  171,   53,  171,  171,  171,  171,

      171,   57,  171,  171,  171,  109,  171,    0,    0,  139,
        0,    0,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  137,  138,  171,   63,   64,  171,   68,   70,  171,
      171,   14,   15,  171,   16,   21,   74,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  164,   27,   28,  171,
      171,  171,  171,  171,  171,  171,   31,  171,  171,   33,
       89,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,   42,  171,   44,  171,  171,  171,  171,  171,  171,
      100,  171,  171,  171,  101,  171,  171,  171,   51,   52,
       54,   55,  171,  171,  171,  171,   59,  108,  171,    0,

        0,    0,    0,  136,  171,  171,  171,  171,  171,  134,
      171,  171,  171,   66,  171,   13,  171,  171,  171,   76,
      171,   23,  171,  171,   19,   20,  171,  171,  171,   25,
      171,   29,  171,  128,  171,  171,  129,  171,  171,  171,
      131,  171,  171,  171,   94,   95,   43,   45,  171,   96,
       47,   48,   49,   97,  171,  171,  171,  104,  105,  171,
       56,  171,  171,  171,  171,    0,    0,  141,    0,  171,
      171,  171,  171,  171,  133,  171,  171,   11,  171,   73,
      171,  171,   22,  171,   79,   81,  171,   26,  171,  171,
      171,   36,  171,  130,   92,  171,  171,  171,  171,  171,

      103,  171,  107,  171,   60,   61,  143,    0,  140,  171,
      171,    2,   62,    3,  171,    4,   72,   75,  171,   24,
      171,   83,  171,  171,  171,   37,  171,  171,  171,  171,
       98,  106,   58,  142,    1,  135,  171,  171,  171,   30,
       32,   87,   93,   38,  171,  171,  132,   17,  171,   46,
      171,  171,  171,  171,   50,  171,  171,   82,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    7,    1,
        1,    8,    9,    1,    1,    1,   10,   11,   12,   12,
       12,   12,   12,   12,   12,   12,   12,    1,    1,    1,
        1,    1,    1,   13,   14,   14,   14,   14,   14,   14,
       15,   15,   15,   15,   15,   16,   15,   15,   15,   15,
       15,   15,   15,   15,   17,   15,   15,   15,   15,   15,
        1,   18,    1,    1,   19,   20,   21,   22,   23,   24,

       25,   26,   27,   28,   29,   15,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   45,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[46] =
    {   0,
        1,    1,    2,    3,    4,    1,    1,    5,    6,    6,
        7,    7,    1,    8,    9,    9,    9,    1,    8,   10,
        8,    8,    8,    8,    8,    8,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9
    } ;

static yyconst flex_int16_t yy_base[678] =
    {   0,
        0,    0,   43,   45,   51,   53,   61,   64,   55,   67,
      443, 2118, 2118, 2118,  426, 2118,    0,  404,   64,   77,
       88,   71,   65,  110, 2118,  101,  106,  140,  135,  145,
      178,   74,   69,  208,   90,  133,  168,  142,  174,   72,
      236,  205,  270,  210,  239,    0, 2118,  406,   42,    0,
     2118,  400,   82,  106,  378, 2118,  385, 2118,  372,    0,
     2118,  370, 2118, 2118,    0,  359,  348, 2118, 2118,    0,
      212, 2118,  333, 2118,    0,  318,  295,   98,  293,    0,
      126,  244,  137,  180,  290,  189,  186,  246,  192,  241,
      225,  262,  276,  279,  272,  308,  286,  312,  293,  194,

      323,  325,  327,  329,  331,  333,  341,  346,  348,  353,
      357,  359,  363,  369,  371,  367,  373,  378,  381,  383,
      394,  396,  401,  403,  405,  260,  407,  412,  414,  423,
      420,  427,  429,  437,  439,  442,  456,  444,  447,  461,
      459,  467,  463,  483,  480,  485,  491,  487,  494,  498,
      500,  505,  514,  510,  516,  518,  525,  521,  533,  529,
      540,  543,  548,    0, 2118,  120,  162, 2118,    0, 2118,
      556,  558, 2118,  561, 2118,  563,  310,  321, 2118,    0,
     2118, 2118,  314,  309,    0, 2118,    0,  274,  276,  281,
      264,  255,    0,  273,    0,  563,  557,  572,  574,  579,

      577,  581,  583,  585,  587,  589,  596,  591,  613,  615,
      618,  620,  622,  624,  629,  631,  635,  639,  648,  650,
      654,  656,  660,  662,  664,  666,  669,  677,  681,  685,
      689,  692,  697,  699,  701,  703,  710,  712,  719,  725,
      730,  727,  732,  734,  743,  740,  745,  747,  751,  754,
      757,  759,  761,  770,  772,  774,  778,  780,  782,  784,
      786,  790,  793,  796,  798,  802,  807,  812,  814,  816,
      818,  825,  827,  829,  833,  836,  838,  840,  846,  848,
      855,  862,  859,  866,  869,  874,  876,  878,  886,  888,
      880,  890,  892,  894,  899,  912,  914,  896, 2118,  265,

      234,  241,  204,  201,    0,  918,  920,  923,  925,  928,
      934,  939,  941,  943,  947,  949,  952,  954,  956,  958,
      960,  962,  971,  977,  980,  983,  985,  987,  991,  993,
      995,  999, 1004, 1006, 1008, 1010, 1013, 1015, 1017, 1020,
     1022, 1030, 1037, 1039, 1046, 1049, 1051, 1053, 1056, 1058,
     1060, 1062, 1064, 1071, 1073, 1068, 1080, 1087, 1082, 1091,
     1093, 1095, 1097, 1099, 1101, 1104, 1106, 1111, 1120, 1125,
     1127, 1129, 1133, 1136, 1140, 1142, 1144, 1149, 1151, 1155,
     1159, 1163, 1161, 1166, 1172, 1177, 1180, 1182, 1189, 1193,
     1195, 1197, 1200, 1205, 1207, 1210, 1214, 1216, 1220, 1224,

     1227, 1231, 1233, 1236, 1239, 1241, 1246,  193,  185, 2118,
      169,  148, 1243, 1255, 1251, 1258, 1266, 1270, 1273, 1275,
     1279, 1277, 1281, 1285, 1287, 1289, 1291, 1293, 1296, 1301,
     1304, 1306, 1308, 1311, 1313, 1315, 1317, 1322, 1324, 1326,
     1329, 1335, 1337, 1343, 1345, 1347, 1350, 1352, 1354, 1356,
     1360, 1362, 1364, 1366, 1375, 1379, 1381, 1386, 1388, 1391,
     1395, 1397, 1399, 1402, 1408, 1404, 1412, 1415, 1417, 1425,
     1428, 1430, 1433, 1435, 1438, 1441, 1443, 1448, 1451, 1453,
     1455, 1461, 1463, 1469, 1471, 1473, 1475, 1482, 1484, 1490,
     1492, 1494, 1498, 1500, 1502, 1504, 1506, 1508, 1510,  153,

      138,  131,  134, 1515, 1517, 1519, 1523, 1526, 1529, 1534,
     1536, 1539, 1544, 1541, 1549, 1557, 1559, 1564, 1566, 1568,
     1570, 1572, 1574, 1576, 1578, 1581, 1585, 1595, 1597, 1599,
     1601, 1603, 1605, 1607, 1609, 1613, 1621, 1624, 1626, 1628,
     1630, 1632, 1634, 1636, 1640, 1643, 1647, 1649, 1652, 1656,
     1658, 1660, 1663, 1665, 1668, 1670, 1672, 1674, 1676, 1678,
     1680, 1682, 1688, 1684, 1693,  130,   86, 2118,   74, 1696,
     1699, 1701, 1706, 1715, 1717, 1720, 1723, 1725, 1729, 1727,
     1731, 1734, 1736, 1738, 1746, 1748, 1752, 1754, 1757, 1759,
     1763, 1767, 1769, 1772, 1775, 1778, 1780, 1786, 1789, 1793,

     1795, 1797, 1799, 1802, 1804, 1808, 2118,   34, 2118, 1813,
     1817, 1819, 1821, 1823, 1827, 1829, 1831, 1833, 1835, 1837,
     1839, 1841, 1844, 1846, 1850, 1852, 1856, 1861, 1863, 1866,
     1872, 1874, 1876, 2118, 1879, 1881, 1885, 1887, 1890, 1892,
     1894, 1896, 1898, 1901, 1905, 1907, 1909, 1913, 1915, 1917,
     1920, 1922, 1924, 1926, 1928, 1930, 1939, 1942, 2118, 1968,
     1978, 1988, 1998, 2001, 2010, 2014, 2023, 2033, 2043, 2053,
     2063, 2073, 2083, 2092, 2102, 2106, 2108
    } ;

static yyconst flex_int16_t yy_def[678] =
    {   0,
      659,    1,  660,  660,  661,  661,  662,  662,  663,  663,
      659,  659,  659,  659,  659,  659,  664,  665,  659,  659,
      659,  659,  666,  666,  659,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  667,  659,  659,  668,  669,
      659,  659,  670,  671,  672,  659,  659,  659,  672,  673,
      659,  659,  659,  659,  664,  659,  674,  659,  659,  675,
      659,  659,  659,  659,  676,  659,  659,  659,  659,  677,
      666,  677,  666,  666,   24,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,

      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  667,  659,  668,  668,  659,  669,  659,
      670,  670,  659,  671,  659,  671,  672,  672,  659,  673,
      659,  659,  659,  659,  675,  659,  676,  659,  659,  659,
      659,  659,  677,  677,  677,  666,   24,  666,  666,  666,

      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  659,  659,

      659,  659,  659,  659,  677,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,

      666,  666,  666,  666,  666,  666,  666,  659,  659,  659,
      659,  659,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  659,

      659,  659,  659,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  659,  659,  659,  659,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,

      666,  666,  666,  666,  666,  666,  659,  659,  659,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  659,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,    0,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659
    } ;

static yyconst flex_int16_t yy_nxt[2164] =
    {   0,
       12,   13,   14,   15,   16,   17,   18,   12,   12,   19,
       20,   21,   22,   23,   23,   23,   23,   12,   24,   25,
       26,   27,   28,   29,   30,   31,   32,   33,   34,   23,
       35,   36,   37,   38,   39,   23,   40,   41,   42,   43,
       44,   45,   23,   23,   23,   47,   48,   47,   48,  167,
       49,  168,   49,   51,   52,   51,   52,   61,   62,   53,
       54,   53,   54,   56,   57,   58,   56,   57,   58,   61,
       62,   68,   69,   70,   63,   80,   80,  634,   59,   80,
       80,   59,   80,   80,   80,   80,   63,   71,   71,  120,
      172,  173,   72,   73,   76,   71,  140,  609,   71,   71,

       80,   80,   74,   72,   73,   77,   71,  119,   78,   79,
      127,   80,   80,   74,  175,  176,   80,   80,  190,   75,
       82,   82,   90,  128,  608,   83,   84,  659,   85,  659,
       86,   91,   87,   88,   94,   89,   80,   80,   92,   95,
       93,  191,   96,   80,   80,   80,   80,   80,   80,   97,
       80,   80,   80,   80,  607,   80,   80,  106,  569,  107,
       98,  129,  568,   99,  100,  101,  130,  102,  108,  167,
      103,  168,  109,  104,  567,  110,  105,  111,   80,   80,
      112,  134,  135,  566,   80,   80,  503,  113,   80,   80,
       80,   80,  131,  502,  136,  196,   80,   80,  114,   80,

       80,  132,   80,   80,   80,   80,  115,  133,  116,  501,
      137,  117,  138,  139,  500,   80,   80,  118,   80,   80,
       80,   80,   71,   71,  204,  203,  219,   72,   73,  148,
       71,  121,  149,  122,  158,   80,   80,   74,  412,  123,
      124,  150,  411,  159,  125,  126,   80,   80,  151,   80,
       80,   80,   80,  207,   82,   82,   80,   80,  141,  193,
      194,  160,   82,  142,  143,  410,  161,  162,  409,  195,
       80,   80,   80,   80,  144,  145,  163,  146,  206,  147,
       80,   80,   80,   80,  205,  408,   80,   80,  305,   80,
       80,  152,  153,  208,  304,  212,   80,   80,  154,  209,

      155,  303,  156,   80,   80,  213,  302,  157,  197,  301,
       81,  300,  198,   81,  210,  299,  199,  211,   80,   80,
      299,  200,   80,   80,  215,  177,  218,  178,  201,  192,
      202,  189,  214,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,   80,   80,  221,  188,  222,  186,  216,
      217,   80,   80,  220,  184,  224,   80,   80,   80,   80,
      225,  223,  226,   80,   80,  182,  227,   80,   80,   80,
       80,  228,  181,   80,   80,  229,  177,   80,   80,   80,
       80,   80,   80,   80,   80,  230,  231,  179,   80,   80,
      232,   80,   80,   80,   80,  178,  233,  235,  234,  237,

      239,  236,  170,  238,   80,   80,   80,   80,  165,  240,
      241,   80,   80,   80,   80,   80,   80,   80,   80,  242,
      243,   67,   80,   80,   80,   80,  245,  244,   64,  251,
       80,   80,  246,   80,   80,  247,  248,   80,   80,   80,
       80,  249,  659,  250,  253,  659,  255,   80,   80,   80,
       80,  252,   80,   80,   80,   80,  254,   80,   80,  258,
      659,  256,  659,  260,  261,  257,   80,   80,  266,   80,
       80,   80,   80,   80,   80,  259,  262,   80,   80,  659,
      265,  268,  659,  267,  263,  659,  269,  272,  659,  264,
       80,   80,  271,   80,   80,   80,   80,   80,   80,  270,

      273,   80,   80,  275,   80,   80,  659,  274,   80,   80,
       80,   80,  659,  278,  277,   80,   80,  659,  280,  276,
       80,   80,  281,  279,   80,   80,   80,   80,   80,   80,
      282,   80,   80,  659,  285,   80,   80,  283,  287,   80,
       80,  284,  288,   80,   80,  659,  290,  659,  286,  289,
       80,   80,  291,   80,   80,  659,  295,  292,   80,   80,
      659,  293,  659,  294,  659,  659,  172,  173,  296,  659,
      659,  659,  176,   80,   80,  197,  659,   81,  659,   81,
       81,  297,   80,   80,   80,   80,  298,   80,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,

       80,   80,   80,  659,  309,  311,   80,   80,  659,  313,
      306,  307,  308,  310,  659,  312,  317,  659,  314,  659,
      315,  659,  318,   80,   80,   80,   80,  316,   80,   80,
       80,   80,   80,   80,   80,   80,  659,  319,  659,   80,
       80,   80,   80,  659,  323,   80,   80,  659,  320,   80,
       80,  659,  322,  324,  659,  325,  659,  327,   80,   80,
       80,   80,  659,  321,   80,   80,   80,   80,  659,  326,
       80,   80,   80,   80,   80,   80,   80,   80,  328,   80,
       80,  659,  335,  330,  336,  659,  329,   80,   80,  338,
      331,   80,   80,  332,  659,   80,   80,  333,  334,   80,

       80,  339,   80,   80,  659,  337,  341,   80,   80,   80,
       80,   80,   80,   80,   80,  659,  343,  340,  659,  345,
       80,   80,   80,   80,  659,  342,  659,  347,  344,   80,
       80,  659,  349,  659,  346,   80,   80,   80,   80,  350,
       80,   80,   80,   80,   80,   80,  659,  348,  659,  351,
       80,   80,  352,   80,   80,   80,   80,   80,   80,  354,
      353,   80,   80,  659,   80,   80,  659,   80,   80,   80,
       80,   80,   80,  355,  361,  360,  356,  362,  358,  357,
       80,   80,   80,   80,   80,   80,  359,  364,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,  365,  659,

       80,   80,  363,   80,   80,  367,   80,   80,   80,   80,
      368,  366,   80,   80,  659,  370,  371,   80,   80,  659,
      369,  374,   80,   80,   80,   80,   80,   80,   80,   80,
      659,  376,  375,  372,  373,   80,   80,   80,   80,   80,
       80,  659,  377,   80,   80,  659,   80,   80,   80,   80,
       80,   80,  379,  382,  659,  378,   80,   80,   80,   80,
      659,  380,  386,  381,  384,   80,   80,  659,  388,   80,
       80,  383,   80,   80,  659,  385,   80,   80,  387,   80,
       80,  659,  389,  392,   80,   80,   80,   80,   80,   80,
       80,   80,  390,  393,  659,  391,   80,   80,   80,   80,

       80,   80,   80,   80,   80,   80,   80,   80,  395,   80,
       80,  659,  394,  400,  403,  402,  396,  659,  397,  404,
      659,  398,   80,   80,   80,   80,  399,  401,   80,   80,
       80,   80,  407,   80,   80,   80,   80,  659,   80,   80,
      659,  406,  405,  413,   80,   80,  659,  414,  417,   80,
       80,   80,   80,   80,   80,  415,  418,   80,   80,   80,
       80,  416,   80,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,   80,  659,  420,  659,  419,  659,  422,
      421,   80,   80,  423,  659,  424,  426,   80,   80,  425,
       80,   80,  427,   80,   80,   80,   80,   80,   80,  659,

      428,   80,   80,   80,   80,   80,   80,  659,  430,   80,
       80,  659,  429,  431,   80,   80,   80,   80,   80,   80,
       80,   80,  659,   80,   80,   80,   80,   80,   80,  659,
       80,   80,   80,   80,  434,  659,  432,  659,  435,  437,
       80,   80,  433,  439,  441,  659,  436,   80,   80,   80,
       80,  659,  442,  659,  438,  440,   80,   80,  443,   80,
       80,   80,   80,   80,   80,  659,   80,   80,   80,   80,
       80,   80,   80,   80,   80,   80,  444,  447,   80,   80,
      450,   80,   80,   80,   80,  445,  448,  446,  454,  452,
       80,   80,   80,   80,  453,  659,  449,   80,   80,  659,

      451,   80,   80,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,  659,   80,   80,   80,   80,  455,  659,
      457,   80,   80,  456,  659,  460,  659,  458,  659,  459,
       80,   80,  659,  461,  462,   80,   80,   80,   80,   80,
       80,  659,  463,   80,   80,  465,   80,   80,  659,  467,
       80,   80,   80,   80,   80,   80,  464,  468,  466,   80,
       80,   80,   80,  659,  469,   80,   80,  659,  470,   80,
       80,   80,   80,   80,   80,  472,   80,   80,  659,  473,
      659,  475,   80,   80,  659,  471,  476,   80,   80,  478,
       80,   80,   80,   80,  480,  659,  477,  474,  479,   80,

       80,  659,  482,   80,   80,   80,   80,   80,   80,  483,
       80,   80,  659,  481,  659,   80,   80,   80,   80,  484,
       80,   80,  659,  486,   80,   80,   80,   80,  487,  489,
       80,   80,  659,  488,   80,   80,  485,   80,   80,  659,
      491,   80,   80,   80,   80,  490,   80,   80,  492,   80,
       80,   80,   80,   80,   80,  495,   80,   80,  493,  659,
      494,   80,   80,  498,  659,   80,   80,  504,   80,   80,
      659,  496,  497,  659,  499,  505,   80,   80,  659,  506,
       80,   80,  507,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,  659,  508,   80,   80,   80,   80,   80,

       80,   80,   80,   80,   80,  513,   80,   80,  509,  510,
      512,   80,   80,  511,   80,   80,   80,   80,   80,   80,
      659,   80,   80,   80,   80,   80,   80,   80,   80,  514,
      659,  515,   80,   80,   80,   80,   80,   80,  659,   80,
       80,  659,  516,  517,  519,   80,   80,   80,   80,  659,
      520,  521,  518,   80,   80,   80,   80,   80,   80,  522,
       80,   80,   80,   80,   80,   80,   80,   80,  659,  523,
       80,   80,   80,   80,   80,   80,   80,   80,  528,  526,
      524,  659,  527,  525,  659,   80,   80,  659,  529,   80,
       80,   80,   80,  659,  531,  533,   80,   80,   80,   80,

      530,   80,   80,  659,  532,   80,   80,   80,   80,   80,
       80,  535,   80,   80,   80,   80,  536,  534,   80,   80,
      659,  537,   80,   80,  541,   80,   80,   80,   80,  659,
      539,  659,  538,  659,  540,   80,   80,  543,   80,   80,
       80,   80,  544,   80,   80,   80,   80,  545,   80,   80,
      542,   80,   80,   80,   80,  659,  547,  659,   80,   80,
      546,   80,   80,   80,   80,   80,   80,  659,  550,  549,
      551,   80,   80,   80,   80,  659,  548,  552,  659,   80,
       80,   80,   80,   80,   80,   80,   80,  659,  554,  556,
      659,  553,   80,   80,   80,   80,  659,  557,  558,  555,

       80,   80,   80,   80,   80,   80,  659,  559,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
       80,   80,  560,  659,  564,   80,   80,   80,   80,   80,
       80,  659,  563,   80,   80,  562,   80,   80,  561,   80,
       80,  659,  565,  572,   80,   80,   80,   80,  659,   80,
       80,   80,   80,  570,   80,   80,  659,  571,  659,   80,
       80,  659,  574,  576,  573,  659,  577,   80,   80,   80,
       80,  659,  575,  578,   80,   80,   80,   80,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
      582,   80,   80,  659,  584,   80,   80,  659,  579,  659,

      583,  659,  580,  659,  581,   80,   80,   80,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
       80,  659,  586,   80,   80,  588,  589,  659,  585,  590,
      587,   80,   80,  591,   80,   80,   80,   80,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,  659,  593,
       80,   80,  594,   80,   80,  659,  595,   80,   80,   80,
       80,  597,   80,   80,  659,  592,   80,   80,   80,   80,
       80,   80,  596,   80,   80,   80,   80,  598,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,   80,   80,   80,  659,  601,   80,   80,

      659,  599,  659,   80,   80,  659,   80,   80,  600,   80,
       80,   80,   80,  659,  603,  602,   80,   80,  604,  606,
      610,  659,  605,  659,  612,   80,   80,   80,   80,  659,
       80,   80,  611,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,  613,   80,   80,   80,   80,   80,   80,
      659,  614,  615,  617,  659,  618,   80,   80,   80,   80,
      659,  616,   80,   80,   80,   80,  621,   80,   80,   80,
       80,  659,  619,   80,   80,  659,  620,   80,   80,   80,
       80,  624,   80,   80,  622,   80,   80,  623,   80,   80,
       80,   80,  659,  626,  659,  625,   80,   80,  628,   80,

       80,  659,  627,   80,   80,   80,   80,   80,   80,   80,
       80,  629,   80,   80,   80,   80,  659,  631,   80,   80,
      659,  630,  659,   80,   80,  659,  633,   80,   80,   80,
       80,   80,   80,   80,   80,  632,  635,   80,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,  636,   80,   80,   80,   80,  659,  638,
       80,   80,   80,   80,  659,  637,   80,   80,  640,  659,
      641,   80,   80,   80,   80,  639,   80,   80,  659,  643,
      659,  645,   80,   80,   80,   80,   80,   80,  642,   80,
       80,   80,   80,  659,  646,   80,   80,   80,   80,  644,

       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
      648,   80,   80,  659,  649,   80,   80,   80,   80,   80,
       80,  659,  647,   80,   80,   80,   80,   80,   80,  659,
       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
       80,   80,  659,  650,  653,  659,  654,  655,  659,   80,
       80,  651,   80,   80,  659,  652,  659,  659,  659,  659,
      659,  659,  656,  658,  659,  659,  659,  657,   46,   46,
       46,   46,   46,   46,   46,   46,   46,   46,   50,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   55,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   60,   60,

       60,   60,   60,   60,   60,   60,   60,   60,   65,   65,
       66,  659,   66,   66,   66,   66,   66,   66,   66,   66,
       81,   81,   81,  164,  659,  659,  164,  659,  164,  164,
      164,  164,  164,  166,  659,  659,  166,  166,  166,  166,
      166,  166,  166,  169,  659,  659,  169,  169,  659,  169,
      169,  169,  169,  171,  659,  659,  171,  171,  171,  171,
      171,  171,  171,  174,  659,  659,  174,  174,  174,  174,
      174,  174,  174,  177,  659,  659,  659,  177,  177,  177,
      177,  177,  177,  180,  659,  659,  180,  180,  180,  180,
      180,  180,  183,  659,  183,  183,  183,  183,  183,  183,

      183,  183,  185,  659,  659,  185,  185,  185,  185,  185,
      185,  185,  187,  187,   80,   80,   80,   11,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659
    } ;

static yyconst flex_int16_t yy_chk[2164] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,    4,    4,   49,
        3,   49,    4,    5,    5,    6,    6,    9,    9,    5,
        5,    6,    6,    7,    7,    7,    8,    8,    8,   10,
       10,   19,   19,   19,    9,   23,   23,  608,    7,   33,
       33,    8,   40,   40,   32,   32,   10,   20,   20,   33,
       53,   53,   20,   20,   22,   20,   40,  569,   21,   21,

       35,   35,   20,   21,   21,   22,   21,   32,   22,   22,
       35,   26,   26,   21,   54,   54,   27,   27,   78,   20,
       24,   24,   26,   35,  567,   24,   24,  166,   24,  166,
       24,   26,   24,   24,   27,   24,   81,   81,   26,   27,
       26,   78,   27,   36,   36,   29,   29,   83,   83,   27,
       28,   28,   38,   38,  566,   30,   30,   29,  503,   29,
       28,   36,  502,   28,   28,   28,   36,   28,   29,  167,
       28,  167,   29,   28,  501,   30,   28,   30,   37,   37,
       30,   38,   38,  500,   39,   39,  412,   30,   31,   31,
       84,   84,   37,  411,   39,   84,   87,   87,   31,   86,

       86,   37,   89,   89,  100,  100,   31,   37,   31,  409,
       39,   31,   39,   39,  408,   42,   42,   31,   34,   34,
       44,   44,   71,   71,   87,   86,  100,   71,   71,   42,
       71,   34,   42,   34,   44,   91,   91,   71,  304,   34,
       34,   42,  303,   44,   34,   34,   41,   41,   42,   45,
       45,   90,   90,   91,   82,   82,   88,   88,   41,   82,
       82,   45,   82,   41,   41,  302,   45,   45,  301,   82,
      126,  126,   92,   92,   41,   41,   45,   41,   90,   41,
       43,   43,   95,   95,   88,  300,   93,   93,  194,   94,
       94,   43,   43,   92,  192,   95,   97,   97,   43,   92,

       43,  191,   43,   99,   99,   95,  190,   43,   85,  189,
       85,  188,   85,   85,   93,  184,   85,   94,   96,   96,
      183,   85,   98,   98,   97,  178,   99,  177,   85,   79,
       85,   77,   96,  101,  101,  102,  102,  103,  103,  104,
      104,  105,  105,  106,  106,  102,   76,  103,   73,   98,
       98,  107,  107,  101,   67,  105,  108,  108,  109,  109,
      106,  104,  107,  110,  110,   66,  107,  111,  111,  112,
      112,  107,   62,  113,  113,  107,   59,  116,  116,  114,
      114,  115,  115,  117,  117,  108,  109,   57,  118,  118,
      110,  119,  119,  120,  120,   55,  111,  113,  112,  114,

      116,  113,   52,  115,  121,  121,  122,  122,   48,  117,
      118,  123,  123,  124,  124,  125,  125,  127,  127,  119,
      120,   18,  128,  128,  129,  129,  122,  121,   15,  125,
      131,  131,  123,  130,  130,  123,  124,  132,  132,  133,
      133,  124,   11,  124,  128,    0,  130,  134,  134,  135,
      135,  127,  136,  136,  138,  138,  129,  139,  139,  133,
        0,  131,    0,  135,  136,  132,  137,  137,  139,  141,
      141,  140,  140,  143,  143,  134,  137,  142,  142,    0,
      138,  140,    0,  139,  137,    0,  140,  142,    0,  137,
      145,  145,  141,  144,  144,  146,  146,  148,  148,  140,

      142,  147,  147,  144,  149,  149,    0,  143,  150,  150,
      151,  151,    0,  146,  145,  152,  152,    0,  148,  144,
      154,  154,  149,  147,  153,  153,  155,  155,  156,  156,
      149,  158,  158,    0,  151,  157,  157,  150,  153,  160,
      160,  150,  154,  159,  159,    0,  156,    0,  152,  155,
      161,  161,  157,  162,  162,    0,  160,  158,  163,  163,
        0,  159,    0,  159,  171,  171,  172,  172,  161,  174,
      174,  176,  176,  196,  196,  197,    0,  197,    0,  197,
      197,  162,  198,  198,  199,  199,  163,  201,  201,  200,
      200,  202,  202,  203,  203,  204,  204,  205,  205,  206,

      206,  208,  208,    0,  201,  202,  207,  207,    0,  203,
      198,  199,  200,  201,    0,  202,  207,    0,  204,    0,
      205,    0,  207,  209,  209,  210,  210,  206,  211,  211,
      212,  212,  213,  213,  214,  214,    0,  209,    0,  215,
      215,  216,  216,    0,  214,  217,  217,    0,  210,  218,
      218,    0,  213,  215,    0,  216,    0,  217,  219,  219,
      220,  220,    0,  212,  221,  221,  222,  222,    0,  216,
      223,  223,  224,  224,  225,  225,  226,  226,  218,  227,
      227,    0,  224,  220,  225,    0,  219,  228,  228,  227,
      221,  229,  229,  222,    0,  230,  230,  223,  223,  231,

      231,  228,  232,  232,    0,  226,  230,  233,  233,  234,
      234,  235,  235,  236,  236,    0,  232,  229,    0,  234,
      237,  237,  238,  238,    0,  231,    0,  236,  233,  239,
      239,    0,  238,    0,  235,  240,  240,  242,  242,  239,
      241,  241,  243,  243,  244,  244,    0,  237,    0,  240,
      246,  246,  241,  245,  245,  247,  247,  248,  248,  243,
      242,  249,  249,    0,  250,  250,    0,  251,  251,  252,
      252,  253,  253,  244,  250,  249,  245,  251,  247,  246,
      254,  254,  255,  255,  256,  256,  248,  253,  257,  257,
      258,  258,  259,  259,  260,  260,  261,  261,  254,    0,

      262,  262,  252,  263,  263,  257,  264,  264,  265,  265,
      258,  255,  266,  266,    0,  261,  262,  267,  267,    0,
      260,  265,  268,  268,  269,  269,  270,  270,  271,  271,
        0,  267,  266,  263,  264,  272,  272,  273,  273,  274,
      274,    0,  268,  275,  275,    0,  276,  276,  277,  277,
      278,  278,  271,  274,    0,  270,  279,  279,  280,  280,
        0,  272,  277,  273,  276,  281,  281,    0,  279,  283,
      283,  275,  282,  282,    0,  276,  284,  284,  278,  285,
      285,    0,  280,  283,  286,  286,  287,  287,  288,  288,
      291,  291,  281,  285,    0,  282,  289,  289,  290,  290,

      292,  292,  293,  293,  294,  294,  298,  298,  287,  295,
      295,    0,  286,  291,  294,  293,  288,    0,  289,  295,
        0,  290,  296,  296,  297,  297,  290,  292,  306,  306,
      307,  307,  298,  308,  308,  309,  309,    0,  310,  310,
        0,  297,  296,  306,  311,  311,    0,  307,  310,  312,
      312,  313,  313,  314,  314,  308,  311,  315,  315,  316,
      316,  309,  317,  317,  318,  318,  319,  319,  320,  320,
      321,  321,  322,  322,    0,  313,    0,  312,    0,  314,
      313,  323,  323,  315,    0,  316,  318,  324,  324,  317,
      325,  325,  319,  326,  326,  327,  327,  328,  328,    0,

      323,  329,  329,  330,  330,  331,  331,    0,  328,  332,
      332,    0,  327,  330,  333,  333,  334,  334,  335,  335,
      336,  336,    0,  337,  337,  338,  338,  339,  339,    0,
      340,  340,  341,  341,  334,    0,  332,    0,  335,  337,
      342,  342,  333,  339,  340,    0,  336,  343,  343,  344,
      344,    0,  341,    0,  338,  339,  345,  345,  342,  346,
      346,  347,  347,  348,  348,    0,  349,  349,  350,  350,
      351,  351,  352,  352,  353,  353,  345,  348,  356,  356,
      351,  354,  354,  355,  355,  346,  349,  347,  356,  354,
      357,  357,  359,  359,  355,    0,  350,  358,  358,    0,

      352,  360,  360,  361,  361,  362,  362,  363,  363,  364,
      364,  365,  365,    0,  366,  366,  367,  367,  357,    0,
      359,  368,  368,  358,    0,  362,    0,  360,    0,  361,
      369,  369,    0,  365,  366,  370,  370,  371,  371,  372,
      372,    0,  367,  373,  373,  370,  374,  374,    0,  372,
      375,  375,  376,  376,  377,  377,  369,  373,  371,  378,
      378,  379,  379,    0,  374,  380,  380,    0,  375,  381,
      381,  383,  383,  382,  382,  379,  384,  384,    0,  380,
        0,  382,  385,  385,    0,  378,  382,  386,  386,  383,
      387,  387,  388,  388,  385,    0,  382,  381,  384,  389,

      389,    0,  387,  390,  390,  391,  391,  392,  392,  388,
      393,  393,    0,  386,    0,  394,  394,  395,  395,  389,
      396,  396,    0,  393,  397,  397,  398,  398,  393,  394,
      399,  399,    0,  393,  400,  400,  391,  401,  401,    0,
      397,  402,  402,  403,  403,  395,  404,  404,  398,  405,
      405,  406,  406,  413,  413,  401,  407,  407,  399,    0,
      400,  415,  415,  405,    0,  414,  414,  413,  416,  416,
        0,  403,  404,    0,  407,  414,  417,  417,    0,  415,
      418,  418,  416,  419,  419,  420,  420,  422,  422,  421,
      421,  423,  423,    0,  417,  424,  424,  425,  425,  426,

      426,  427,  427,  428,  428,  424,  429,  429,  418,  419,
      421,  430,  430,  420,  431,  431,  432,  432,  433,  433,
        0,  434,  434,  435,  435,  436,  436,  437,  437,  427,
        0,  430,  438,  438,  439,  439,  440,  440,    0,  441,
      441,    0,  431,  434,  439,  442,  442,  443,  443,    0,
      440,  441,  438,  444,  444,  445,  445,  446,  446,  442,
      447,  447,  448,  448,  449,  449,  450,  450,    0,  443,
      451,  451,  452,  452,  453,  453,  454,  454,  450,  446,
      444,    0,  448,  445,    0,  455,  455,    0,  451,  456,
      456,  457,  457,    0,  453,  455,  458,  458,  459,  459,

      452,  460,  460,    0,  454,  461,  461,  462,  462,  463,
      463,  458,  464,  464,  466,  466,  459,  456,  465,  465,
        0,  462,  467,  467,  466,  468,  468,  469,  469,    0,
      464,    0,  463,    0,  465,  470,  470,  468,  471,  471,
      472,  472,  469,  473,  473,  474,  474,  470,  475,  475,
      467,  476,  476,  477,  477,    0,  473,    0,  478,  478,
      471,  479,  479,  480,  480,  481,  481,    0,  477,  476,
      478,  482,  482,  483,  483,    0,  475,  479,    0,  484,
      484,  485,  485,  486,  486,  487,  487,    0,  482,  484,
        0,  480,  488,  488,  489,  489,    0,  486,  487,  483,

      490,  490,  491,  491,  492,  492,    0,  488,  493,  493,
      494,  494,  495,  495,  496,  496,  497,  497,  498,  498,
      499,  499,  493,    0,  497,  504,  504,  505,  505,  506,
      506,    0,  496,  507,  507,  495,  508,  508,  494,  509,
      509,    0,  499,  507,  510,  510,  511,  511,    0,  512,
      512,  514,  514,  505,  513,  513,    0,  506,    0,  515,
      515,    0,  509,  512,  508,    0,  513,  516,  516,  517,
      517,    0,  511,  515,  518,  518,  519,  519,  520,  520,
      521,  521,  522,  522,  523,  523,  524,  524,  525,  525,
      521,  526,  526,    0,  524,  527,  527,    0,  517,    0,

      523,    0,  518,    0,  519,  528,  528,  529,  529,  530,
      530,  531,  531,  532,  532,  533,  533,  534,  534,  535,
      535,    0,  528,  536,  536,  531,  533,    0,  527,  535,
      529,  537,  537,  536,  538,  538,  539,  539,  540,  540,
      541,  541,  542,  542,  543,  543,  544,  544,    0,  539,
      545,  545,  540,  546,  546,    0,  542,  547,  547,  548,
      548,  544,  549,  549,    0,  538,  550,  550,  551,  551,
      552,  552,  543,  553,  553,  554,  554,  549,  555,  555,
      556,  556,  557,  557,  558,  558,  559,  559,  560,  560,
      561,  561,  562,  562,  564,  564,    0,  557,  563,  563,

        0,  555,    0,  565,  565,    0,  570,  570,  556,  571,
      571,  572,  572,    0,  562,  560,  573,  573,  563,  565,
      570,    0,  564,    0,  572,  574,  574,  575,  575,    0,
      576,  576,  571,  577,  577,  578,  578,  580,  580,  579,
      579,  581,  581,  573,  582,  582,  583,  583,  584,  584,
        0,  574,  576,  579,    0,  581,  585,  585,  586,  586,
        0,  577,  587,  587,  588,  588,  586,  589,  589,  590,
      590,    0,  582,  591,  591,    0,  584,  592,  592,  593,
      593,  590,  594,  594,  587,  595,  595,  589,  596,  596,
      597,  597,    0,  593,    0,  591,  598,  598,  597,  599,

      599,    0,  596,  600,  600,  601,  601,  602,  602,  603,
      603,  598,  604,  604,  605,  605,    0,  600,  606,  606,
        0,  599,    0,  610,  610,    0,  604,  611,  611,  612,
      612,  613,  613,  614,  614,  602,  610,  615,  615,  616,
      616,  617,  617,  618,  618,  619,  619,  620,  620,  621,
      621,  622,  622,  611,  623,  623,  624,  624,    0,  619,
      625,  625,  626,  626,    0,  615,  627,  627,  623,    0,
      624,  628,  628,  629,  629,  621,  630,  630,    0,  627,
        0,  629,  631,  631,  632,  632,  633,  633,  625,  635,
      635,  636,  636,    0,  630,  637,  637,  638,  638,  628,

      639,  639,  640,  640,  641,  641,  642,  642,  643,  643,
      638,  644,  644,    0,  639,  645,  645,  646,  646,  647,
      647,    0,  637,  648,  648,  649,  649,  650,  650,    0,
      651,  651,  652,  652,  653,  653,  654,  654,  655,  655,
      656,  656,    0,  645,  651,    0,  652,  653,    0,  657,
      657,  646,  658,  658,    0,  649,    0,    0,    0,    0,
        0,    0,  654,  657,    0,    0,    0,  656,  660,  660,
      660,  660,  660,  660,  660,  660,  660,  660,  661,  661,
      661,  661,  661,  661,  661,  661,  661,  661,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  663,  663,

      663,  663,  663,  663,  663,  663,  663,  663,  664,  664,
      665,    0,  665,  665,  665,  665,  665,  665,  665,  665,
      666,  666,  666,  667,    0,    0,  667,    0,  667,  667,
      667,  667,  667,  668,    0,    0,  668,  668,  668,  668,
      668,  668,  668,  669,    0,    0,  669,  669,    0,  669,
      669,  669,  669,  670,    0,    0,  670,  670,  670,  670,
      670,  670,  670,  671,    0,    0,  671,  671,  671,  671,
      671,  671,  671,  672,    0,    0,    0,  672,  672,  672,
      672,  672,  672,  673,    0,    0,  673,  673,  673,  673,
      673,  673,  674,    0,  674,  674,  674,  674,  674,  674,

      674,  674,  675,    0,    0,  675,  675,  675,  675,  675,
      675,  675,  676,  676,  677,  677,  677,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int d__flex_debug;
int d__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *d_text;
#line 1 "dlexer.l"
#line 11 "dlexer.l"

#include <stdio.h>
#include "tokenizer.h"

int nesting_level;




#line 1183 "dlexer.c"

#define INITIAL 0
#define comment 1
#define nesting_comment 2
#define string_literal 3
#define wysiwyg_literal 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int d_lex_destroy (void );

int d_get_debug (void );

void d_set_debug (int debug_flag  );

YY_EXTRA_TYPE d_get_extra (void );

void d_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *d_get_in (void );

void d_set_in  (FILE * in_str  );

FILE *d_get_out (void );

void d_set_out  (FILE * out_str  );

int d_get_leng (void );

char *d_get_text (void );

int d_get_lineno (void );

void d_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int d_wrap (void );
#else
extern int d_wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( d_text, d_leng, 1, d_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( d_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( d_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, d_in))==0 && ferror(d_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(d_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int d_lex (void);

#define YY_DECL int d_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after d_text and d_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 23 "dlexer.l"

#line 1376 "dlexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! d_in )
			d_in = stdin;

		if ( ! d_out )
			d_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			d_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				d__create_buffer(d_in,YY_BUF_SIZE );
		}

		d__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of d_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 660 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2118 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 24 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 25 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 26 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 27 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 28 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 29 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 30 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 31 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 32 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 33 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 34 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 35 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 36 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 37 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 38 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 39 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 40 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 41 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 42 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 43 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 44 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 45 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 46 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 47 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 48 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 49 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 50 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 51 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 52 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 53 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 54 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 55 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 56 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 57 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 58 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 59 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 60 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 61 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 62 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 63 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 64 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 65 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 66 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 67 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 68 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 69 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 70 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 71 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 72 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 73 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 74 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 75 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 76 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 77 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 78 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 79 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 80 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 81 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 82 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 83 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 84 "dlexer.l"
{ return(TOKENIZER_TYPE); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 86 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 87 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 88 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 89 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 90 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 91 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 92 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 93 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 94 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 95 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 96 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 97 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 98 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 99 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 100 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 101 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 102 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 103 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 104 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 105 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 106 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 107 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 108 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 109 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 110 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 111 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 112 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 113 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 114 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 115 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 116 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 117 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 118 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 119 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 120 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 121 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 122 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 123 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 124 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 125 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 126 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 127 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 128 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 129 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 130 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 131 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 132 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 133 "dlexer.l"
{ return(TOKENIZER_KEYWORD); }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 135 "dlexer.l"
{ BEGIN(comment);     return(TOKENIZER_COMMENT); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 136 "dlexer.l"
{ return(TOKENIZER_COMMENT); }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 137 "dlexer.l"
{ return(TOKENIZER_COMMENT); }
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 138 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 139 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 115:
/* rule 115 can match eol */
YY_RULE_SETUP
#line 140 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 141 "dlexer.l"
{ BEGIN(INITIAL);     return(TOKENIZER_COMMENT); }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 143 "dlexer.l"
{ BEGIN(nesting_comment); nesting_level = (0); return(TOKENIZER_COMMENT); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 144 "dlexer.l"
{ return(TOKENIZER_COMMENT); }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 145 "dlexer.l"
{ return(TOKENIZER_COMMENT); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 146 "dlexer.l"
{ return(TOKENIZER_COMMENT); }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 147 "dlexer.l"
{ nesting_level++; return(TOKENIZER_COMMENT); }
	YY_BREAK
case 122:
/* rule 122 can match eol */
YY_RULE_SETUP
#line 148 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 149 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 124:
/* rule 124 can match eol */
YY_RULE_SETUP
#line 150 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 151 "dlexer.l"
{ if (nesting_level-- == 0) BEGIN(INITIAL);  return(TOKENIZER_COMMENT); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 153 "dlexer.l"
{ return(TOKENIZER_COMMENT); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 155 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 156 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 157 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 158 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 159 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 160 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 161 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 162 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 163 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 164 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 165 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 166 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 167 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 168 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 169 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 170 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 171 "dlexer.l"
{ return(TOKENIZER_DIRECTIVE); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 174 "dlexer.l"
{ BEGIN(string_literal);     return(TOKENIZER_LITERAL); }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 175 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 146:
/* rule 146 can match eol */
YY_RULE_SETUP
#line 176 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 177 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 148:
/* rule 148 can match eol */
YY_RULE_SETUP
#line 178 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 179 "dlexer.l"
{ BEGIN(INITIAL);            return(TOKENIZER_LITERAL); }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 181 "dlexer.l"
{ BEGIN(wysiwyg_literal);    return(TOKENIZER_LITERAL); }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 182 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 152:
/* rule 152 can match eol */
YY_RULE_SETUP
#line 183 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 184 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 154:
/* rule 154 can match eol */
YY_RULE_SETUP
#line 185 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 186 "dlexer.l"
{ BEGIN(INITIAL);            return(TOKENIZER_LITERAL); }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 189 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 190 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 191 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 192 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 193 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 194 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 195 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 196 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 197 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 198 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 199 "dlexer.l"
{ return(TOKENIZER_LITERAL); }
	YY_BREAK
case 167:
/* rule 167 can match eol */
YY_RULE_SETUP
#line 201 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 168:
/* rule 168 can match eol */
YY_RULE_SETUP
#line 202 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 203 "dlexer.l"
{ return(TOKENIZER_NEWLINE); }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 204 "dlexer.l"
{ return(TOKENIZER_TEXT);    }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 205 "dlexer.l"
{ return(TOKENIZER_TEXT);    }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 206 "dlexer.l"
{ return(TOKENIZER_TEXT);    }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 208 "dlexer.l"
ECHO;
	YY_BREAK
#line 2334 "dlexer.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
case YY_STATE_EOF(nesting_comment):
case YY_STATE_EOF(string_literal):
case YY_STATE_EOF(wysiwyg_literal):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed d_in at a new source and called
			 * d_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = d_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( d_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * d_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of d_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					d_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			d_restart(d_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) d_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 660 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 660 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 659);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up d_text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					d_restart(d_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( d_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve d_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void d_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        d_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            d__create_buffer(d_in,YY_BUF_SIZE );
	}

	d__init_buffer(YY_CURRENT_BUFFER,input_file );
	d__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void d__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		d_pop_buffer_state();
	 *		d_push_buffer_state(new_buffer);
     */
	d_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	d__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (d_wrap()) processing, but the only time this flag
	 * is looked at is after d_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void d__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	d_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE d__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) d_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in d__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) d_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in d__create_buffer()" );

	b->yy_is_our_buffer = 1;

	d__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with d__create_buffer()
 * 
 */
    void d__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		d_free((void *) b->yy_ch_buf  );

	d_free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a d_restart() or at EOF.
 */
    static void d__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	d__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then d__init_buffer was _probably_
     * called from d_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void d__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		d__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void d_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	d_ensure_buffer_stack();

	/* This block is copied from d__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from d__switch_to_buffer. */
	d__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void d_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	d__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		d__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void d_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)d_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in d_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)d_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in d_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE d__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) d_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in d__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	d__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to d_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       d__scan_bytes() instead.
 */
YY_BUFFER_STATE d__scan_string (yyconst char * yystr )
{
    
	return d__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to d_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE d__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) d_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in d__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = d__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in d__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up d_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		d_text[d_leng] = (yy_hold_char); \
		(yy_c_buf_p) = d_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		d_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int d_get_lineno  (void)
{
        
    return d_lineno;
}

/** Get the input stream.
 * 
 */
FILE *d_get_in  (void)
{
        return d_in;
}

/** Get the output stream.
 * 
 */
FILE *d_get_out  (void)
{
        return d_out;
}

/** Get the length of the current token.
 * 
 */
int d_get_leng  (void)
{
        return d_leng;
}

/** Get the current token.
 * 
 */

char *d_get_text  (void)
{
        return d_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void d_set_lineno (int  line_number )
{
    
    d_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see d__switch_to_buffer
 */
void d_set_in (FILE *  in_str )
{
        d_in = in_str ;
}

void d_set_out (FILE *  out_str )
{
        d_out = out_str ;
}

int d_get_debug  (void)
{
        return d__flex_debug;
}

void d_set_debug (int  bdebug )
{
        d__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from d_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    d_in = stdin;
    d_out = stdout;
#else
    d_in = (FILE *) 0;
    d_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * d_lex_init()
     */
    return 0;
}

/* d_lex_destroy is for both reentrant and non-reentrant scanners. */
int d_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		d__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		d_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	d_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * d_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *d_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *d_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void d_free (void * ptr )
{
	free( (char *) ptr );	/* see d_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 208 "dlexer.l"



int d_wrap ( void ) {
        {
                /* Silly impossible function call to stop warning of unused functions */
                if ( 0 ) {
                        yyunput(0, "");
                }
        }

    return 1;
}

